@@ -13,9 +13,9 @@ sub test_class { return "Google::Adwords::AccountService"; }
 
 # tests to run
 my %tests = (
-    getAccountInfo          => 1,
-    getClientAccounts       => 1,
-    updateAccountInfo       => 1,
+    getAccountInfo    => 1,
+    getClientAccounts => 1,
+    updateAccountInfo => 1,
 );
 
 sub start_of_each_test : Test(setup)
@@ -23,33 +23,36 @@ sub start_of_each_test : Test(setup)
     my $self = shift;
 
     # set debug to whatever was passed in as param
-    $self->{obj}->debug($self->{debug});
+    $self->{obj}->debug( $self->{debug} );
 }
 
 sub getAccountInfo : Test(no_plan)
 {
     my ($self) = @_;
 
-    $sub_name = (caller 0)[3];
+    $sub_name = ( caller 0 )[3];
     $sub_name =~ s/^.+:://;
-    if (not $tests{$sub_name}) {
+    if ( not $tests{$sub_name} ) {
         return;
     }
 
+    if ( $self->{sandbox} ) {
 
-    if ($self->{sandbox}) {
-    
         my $account_info = $self->{obj}->getAccountInfo();
 
-        ok ($account_info->primaryAddress->emailAddress 
-                eq $self->{obj}->clientEmail, 'getAccountInfo');
-        
+        ok(
+            $account_info->primaryAddress->emailAddress eq
+                $self->{obj}->clientEmail,
+            'getAccountInfo'
+        );
+
     }
     else {
 
         my $soap = Test::MockModule->new('SOAP::Lite');
-        $soap->mock( call => sub {
-            my $xml .= <<'EOF';
+        $soap->mock(
+            call => sub {
+                my $xml .= <<'EOF';
   <getAccountInfoResponse xmlns="">
    <ns1:getAccountInfoReturn
 xmlns:ns1="https://adwords.google.com/api/adwords/v6">
@@ -86,79 +89,83 @@ xmlns:ns1="https://adwords.google.com/api/adwords/v6">
   </getAccountInfoResponse>
 EOF
 
-            $xml = $self->gen_full_response($xml);
-            my $env = SOAP::Deserializer->deserialize($xml);
-            return $env;
-        });
+                $xml = $self->gen_full_response($xml);
+                my $env = SOAP::Deserializer->deserialize($xml);
+                return $env;
+            }
+        );
 
-    
         my $account_info = $self->{obj}->getAccountInfo();
 
-        ok ($account_info->currencyCode eq 'INR', 'getAccountInfo'); 
-        ok ($account_info->customerId == 1133, 'getAccountInfo');
-        ok ($account_info->defaultAdsCoverage->optInSearchNetwork eq 'true',
-                'getAccountInfo');
-        ok ($account_info->emailPromotionsPreferences->newsletterEnabled 
-                eq 'false', 'getAccountInfo');
-        ok ($account_info->primaryAddress->emailAddress 
-                eq 'client_1+rohan.almeida@gmail.com', 'getAccountInfo');
+        ok( $account_info->currencyCode eq 'INR', 'getAccountInfo' );
+        ok( $account_info->customerId == 1133, 'getAccountInfo' );
+        ok( $account_info->defaultAdsCoverage->optInSearchNetwork eq 'true',
+            'getAccountInfo' );
+        ok(
+            $account_info->emailPromotionsPreferences->newsletterEnabled eq
+                'false',
+            'getAccountInfo'
+        );
+        ok(
+            $account_info->primaryAddress->emailAddress eq
+                'client_1+rohan.almeida@gmail.com',
+            'getAccountInfo'
+        );
 
     }
 
-}
+} # end sub getAccountInfo :
 
 sub getClientAccounts : Test(no_plan)
 {
     my $self = shift;
 
-    $sub_name = (caller 0)[3];
+    $sub_name = ( caller 0 )[3];
     $sub_name =~ s/^.+:://;
-    if (not $tests{$sub_name}) {
+    if ( not $tests{$sub_name} ) {
         return;
     }
 
+    if ( $self->{sandbox} ) {
 
-    if ($self->{sandbox}) {
-        
         #my @emails = $self->{obj}->getClientAccounts();
 
-        return; 
+        return;
     }
     else {
 
         my $soap = Test::MockModule->new('SOAP::Lite');
-        $soap->mock( call => sub {
-            my $xml .= <<'EOF';
+        $soap->mock(
+            call => sub {
+                my $xml .= <<'EOF';
   <getClientAccountsResponse xmlns="" />
 EOF
 
-            $xml = $self->gen_full_response($xml);
-            my $env = SOAP::Deserializer->deserialize($xml);
-            return $env;
-        });
+                $xml = $self->gen_full_response($xml);
+                my $env = SOAP::Deserializer->deserialize($xml);
+                return $env;
+            }
+        );
 
-    
         my @emails = $self->{obj}->getClientAccounts;
-        ok (scalar @emails == 0, 'getClientAccounts');
+        ok( scalar @emails == 0, 'getClientAccounts' );
 
     }
 
-
-}
+} # end sub getClientAccounts :
 
 sub updateAccountInfo : Test(no_plan)
 {
     my $self = shift;
 
-    $sub_name = (caller 0)[3];
+    $sub_name = ( caller 0 )[3];
     $sub_name =~ s/^.+:://;
-    if (not $tests{$sub_name}) {
+    if ( not $tests{$sub_name} ) {
         return;
     }
 
+    if ( $self->{sandbox} ) {
 
-    if ($self->{sandbox}) {
-    
         my $account_info = Google::Adwords::AccountInfo->new;
 
         my $billing_address = Google::Adwords::Address->new;
@@ -167,24 +174,25 @@ sub updateAccountInfo : Test(no_plan)
 
         $account_info->billingAddress($billing_address);
 
-
         #my $ret = $self->{obj}->updateAccountInfo($account_info);
-        
+
         return;
 
-    }
+    } # end if ( $self->{sandbox} )
     else {
 
         my $soap = Test::MockModule->new('SOAP::Lite');
-        $soap->mock( call => sub {
-            my $xml .= <<'EOF';
+        $soap->mock(
+            call => sub {
+                my $xml .= <<'EOF';
   <updateAccountInfoResponse xmlns="" />
 EOF
 
-            $xml = $self->gen_full_response($xml);
-            my $env = SOAP::Deserializer->deserialize($xml);
-            return $env;
-        });
+                $xml = $self->gen_full_response($xml);
+                my $env = SOAP::Deserializer->deserialize($xml);
+                return $env;
+            }
+        );
 
         my $account_info = Google::Adwords::AccountInfo->new;
 
@@ -195,12 +203,11 @@ EOF
         $account_info->billingAddress($billing_address);
 
         my $ret = $self->{obj}->updateAccountInfo($account_info);
-        
-        ok ($ret == 1, 'updateAccountInfo');
+
+        ok( $ret == 1, 'updateAccountInfo' );
 
     }
-}
-
+} # end sub updateAccountInfo :
 
 1;
 
